@@ -120,6 +120,8 @@
 ( cd opt/kde/share/doc/HTML/ru/ksysv ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktron ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kttsd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kuser ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kview ; rm -rf common )
@@ -128,6 +130,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcoloredit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/klipper ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kvoctrain ; rm -rf common )
@@ -140,6 +144,8 @@
 ( cd opt/kde/share/doc/HTML/ru/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kompare ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kompmgr ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kontact ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kontact ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konsole ; rm -rf common )
@@ -170,6 +176,8 @@
 ( cd opt/kde/share/doc/HTML/ru/konquest ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kturtle ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kverbos ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwallet ; rm -rf common )
@@ -186,6 +194,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kioslave ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/knetattach ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license )
@@ -210,6 +220,8 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 9.png )
@@ -240,6 +252,8 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1.png )
@@ -252,8 +266,12 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 10.png )
@@ -270,6 +288,10 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-localised.css.template )
@@ -324,6 +346,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/passwords ; rm -rf common )
@@ -388,8 +412,26 @@
 ( cd opt/kde/share/doc/HTML/ru/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kamera ; rm -rf common )
@@ -406,6 +448,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kgamma ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdevelop ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/klatin ; rm -rf common )
@@ -456,12 +500,16 @@
 ( cd opt/kde/share/doc/HTML/ru/kcharselect ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/quanta ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/quanta ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kuickshow ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kuickshow ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kolourpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kde_app_devel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kiconedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/klettres ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kghostview ; rm -rf common )
@@ -476,8 +524,6 @@
 ( cd opt/kde/share/doc/HTML/ru/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kenolaba ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwatchgnupg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kworldclock ; rm -rf common )
@@ -488,6 +534,8 @@
 ( cd opt/kde/share/doc/HTML/ru/ksokoban ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kteatime ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmathtool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmathtool ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pci ; rm -rf common )
@@ -518,6 +566,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/ioports ; rm -rf common )
